@@ -31,6 +31,7 @@
 import shelve
 import os
 import wx
+import sys
 
 # Fixme: Hack to force 'image_slice' to be added via Category to Theme class:
 import enthought.traits.ui.wx
@@ -72,6 +73,7 @@ from idockable \
 from idock_ui_provider \
     import IDockUIProvider
 
+is_mac = (sys.platform == 'darwin')
 
 #-------------------------------------------------------------------------------
 #  Global data:  
@@ -304,9 +306,6 @@ class DockWindow ( HasPrivateTraits ):
         self.control  = control = wx.Window( parent, wid, pos, size, style )
         control.owner = self
 
-        # Set up the 'erase background' event handler:
-        wx.EVT_ERASE_BACKGROUND( control, self._erase_background )
- 
         # Set up the 'paint' event handler:
         wx.EVT_PAINT( control, self._paint )
         wx.EVT_SIZE(  control, self._size )
@@ -460,7 +459,6 @@ class DockWindow ( HasPrivateTraits ):
         """
         control = self.control
         if control is not None:
-            wx.EVT_ERASE_BACKGROUND( control, None )
             wx.EVT_PAINT(            control, None )
             wx.EVT_SIZE(             control, None )
             wx.EVT_LEFT_DOWN(        control, None )
@@ -478,6 +476,11 @@ class DockWindow ( HasPrivateTraits ):
     def _paint ( self, event ):
         """ Handles repainting the window.
         """
+        # There is a problem on macs where we get paints when the update
+        # is entirely within children. 
+        if is_mac and self._is_child_paint():
+            return
+        
         sizer = self.sizer
         if isinstance( sizer, DockSizer ):
             sizer.Draw( self.control )
@@ -485,14 +488,21 @@ class DockWindow ( HasPrivateTraits ):
             clear_window( self.control )
         
     #---------------------------------------------------------------------------
-    #  Handles erasing the window background:  
+    #  Uses wx calls to determine if we really need to paint or the children will
+    #  do it.
     #---------------------------------------------------------------------------
-                
-    def _erase_background ( self, event ):
-        """ Handles erasing the window background.
+
+    def _is_child_paint ( self ):
+        """ Returns whether or not the current update region is entirely within a child.
         """
-        pass
-        
+        if self.control.Children:
+            update_rect = self.control.UpdateRegion.Box
+            for child in self.control.Children:
+                if not child.HasTransparentBackground() and \
+                        child.Rect.ContainsRect(update_rect):
+                    return True
+        return False
+
     #---------------------------------------------------------------------------
     #  Handles the window being resized:  
     #---------------------------------------------------------------------------
